@@ -42,6 +42,8 @@ class Config
         bool bSubDirectories;
         bool bUseCache;
         bool bUpdateCache;
+        bool bSaveSerials;
+        bool bPlatformDetection;
         std::string sGameRegex;
         std::string sDirectory;
         std::string sCacheDirectory;
@@ -63,6 +65,11 @@ class Config
         std::string sLanguagePackSubdir;
         std::string sDLCSubdir;
         std::string sGameSubdir;
+	std::string sLanguagePriority;
+	std::string sPlatformPriority;
+	std::vector<unsigned int> vLanguagePriority;
+	std::vector<unsigned int> vPlatformPriority;
+
         unsigned int iInstallerType;
         unsigned int iInstallerLanguage;
         int iRetries;
