@@ -13,7 +13,7 @@
 #include <boost/filesystem.hpp>
 #include <boost/program_options.hpp>
 
-#define VERSION_NUMBER "2.19"
+#define VERSION_NUMBER "2.21"
 
 #ifndef VERSION_STRING
 #   define VERSION_STRING "LGOGDownloader " VERSION_NUMBER
@@ -26,6 +26,40 @@ template<typename T> void set_vm_value(std::map<std::string, bpo::variable_value
     vm[option].value() = boost::any(value);
 }
 
+// Parse the priority string, making it an array of numeric codes, and override the ORed type if required
+void handle_priority(const std::string &what, const std::string &priority_string, std::vector<unsigned int> &priority, unsigned int &type)
+{
+    size_t idx = 0, found;
+
+    while ((found = priority_string.find(',', idx)) != std::string::npos)
+	{
+	    priority.push_back(std::stoi(priority_string.substr(idx, found - idx)));
+	    idx = found + 1;
+	}
+    priority.push_back(std::stoi(priority_string.substr(idx)));
+
+    unsigned int wanted = 0;
+    #ifdef DEBUG
+        std::cerr << "DEBUG INFO (handle_priority): for " << what << " found ";
+    #endif
+    for (std::vector<unsigned int>::iterator it = priority.begin(); it != priority.end(); it++)
+	{
+	    wanted += *it;
+            #ifdef DEBUG
+  	      std::cerr << *it << " ";
+            #endif
+	}
+    #ifdef DEBUG
+        std::cerr << std::endl;
+    #endif
+
+    if (wanted != type)
+	{
+            type = wanted;
+	    std::cout << "Warning: for " << what << " the priority string doesn't match the enabled installers, forcing enabled installers to " << type << std::endl;
+	}
+}
+
 int main(int argc, char *argv[])
 {
     Config config;
@@ -68,6 +102,8 @@ int main(int argc, char *argv[])
 
     // Help text for subdir options
     std::string subdir_help_text = "\nTemplates:\n- %platform%\n- %gamename%\n- %dlcname%";
+    // Help text for priority options
+    std::string priority_help_text = "\nIf set, only the first matching one will be downloaded. If unset, all matching combinations will be downloaded.\nSyntax: use a string separated by \",\"";
 
     std::vector<std::string> unrecognized_options_cfg;
     bpo::variables_map vm;
@@ -92,6 +128,7 @@ int main(int argc, char *argv[])
         bool bNoDeb = false;
         bool bNoTarGz = false;
         bool bNoCover = false;
+        bool bNoPlatformDetection = false;
         config.bReport = false;
         // Commandline options (no config file)
         options_cli_no_cfg.add_options()
@@ -102,7 +139,7 @@ int main(int argc, char *argv[])
             ("list-details", bpo::value<bool>(&config.bListDetails)->zero_tokens()->default_value(false), "List games with detailed info")
             ("download", bpo::value<bool>(&config.bDownload)->zero_tokens()->default_value(false), "Download")
             ("repair", bpo::value<bool>(&config.bRepair)->zero_tokens()->default_value(false), "Repair downloaded files\nUse --repair --download to redownload files when filesizes don't match (possibly different version). Redownload will rename the old file (appends .old to filename)")
-            ("game", bpo::value<std::string>(&config.sGameRegex)->default_value(""), "Set regular expression filter\nfor download/list/repair (Perl syntax)\nAliases: \"all\", \"free\"")
+            ("game", bpo::value<std::string>(&config.sGameRegex)->default_value(""), "Set regular expression filter\nfor download/list/repair (Perl syntax)\nAliases: \"all\", \"free\"\nAlias \"free\" doesn't work with cached details")
             ("create-xml", bpo::value<std::string>(&config.sXMLFile)->default_value(""), "Create GOG XML for file\n\"automatic\" to enable automatic XML creation")
             ("update-check", bpo::value<bool>(&config.bUpdateCheck)->zero_tokens()->default_value(false), "Check for update notifications")
             ("check-orphans", bpo::value<std::string>(&config.sOrphanRegex)->implicit_value(""), check_orphans_text.c_str())
@@ -112,6 +149,7 @@ int main(int argc, char *argv[])
             ("report", bpo::value<std::string>(&config.sReportFilePath)->implicit_value("lgogdownloader-report.log"), "Save report of downloaded/repaired files to specified file\nDefault filename: lgogdownloader-report.log")
             ("no-cover", bpo::value<bool>(&bNoCover)->zero_tokens()->default_value(false), "Don't download cover images. Overrides --cover option.\nUseful for making exceptions when \"cover\" is set to true in config file.")
             ("update-cache", bpo::value<bool>(&config.bUpdateCache)->zero_tokens()->default_value(false), "Update game details cache")
+            ("no-platform-detection", bpo::value<bool>(&bNoPlatformDetection)->zero_tokens()->default_value(false), "Don't try to detect supported platforms from game shelf.\nSkips the initial fast platform detection and detects the supported platforms from game details which is slower but more accurate.\nUseful in case platform identifier is missing for some games in the game shelf.\nUsing --platform with --list doesn't work with this option.")
         ;
         // Commandline options (config file)
         options_cli_cfg.add_options()
@@ -148,6 +186,9 @@ int main(int argc, char *argv[])
             ("subdir-game", bpo::value<std::string>(&config.sGameSubdir)->default_value("%gamename%"), ("Set subdirectory for game" + subdir_help_text).c_str())
             ("use-cache", bpo::value<bool>(&config.bUseCache)->zero_tokens()->default_value(false), ("Use game details cache"))
             ("cache-valid", bpo::value<int>(&config.iCacheValid)->default_value(2880), ("Set how long cached game details are valid (in minutes)\nDefault: 2880 minutes (48 hours)"))
+            ("language-priority", bpo::value<std::string>(&config.sLanguagePriority)->default_value(""), ("Set priority of systems" + priority_help_text + ", like \"4,1\" for French first, then English if no French version").c_str())
+            ("platform-priority", bpo::value<std::string>(&config.sPlatformPriority)->default_value(""), ("Set priority of platforms" + priority_help_text + ", like \"4,1\" for Linux first, then Windows if no Linux version").c_str())
+            ("save-serials", bpo::value<bool>(&config.bSaveSerials)->zero_tokens()->default_value(false), "Save serial numbers when downloading")
         ;
         // Options read from config file
         options_cfg_only.add_options()
@@ -296,10 +337,18 @@ int main(int argc, char *argv[])
         config.bDLC = !bNoDLC;
         config.bRemoteXML = !bNoRemoteXML;
         config.bSubDirectories = !bNoSubDirectories;
+        config.bPlatformDetection = !bNoPlatformDetection;
 
         // Override cover option
         if (bNoCover)
             config.bCover = false;
+
+	// Handle priority business
+	if (!config.sLanguagePriority.empty())
+	    handle_priority("languages", config.sLanguagePriority, config.vLanguagePriority, config.iInstallerLanguage);
+	if (!config.sPlatformPriority.empty())
+	    handle_priority("platforms", config.sPlatformPriority, config.vPlatformPriority, config.iInstallerType);
+
     }
     catch (std::exception& e)
     {
@@ -370,6 +419,10 @@ int main(int argc, char *argv[])
             return 1;
     }
 
+    // Make sure that config file and cookie file are only readable/writable by owner
+    Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+    Util::setFilePermissions(config.sCookiePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
+
     if (config.bSaveConfig || iLoginResult == 1)
     {
         if (iLoginResult == 1)
@@ -426,6 +479,7 @@ int main(int argc, char *argv[])
                 }
             }
             ofs.close();
+            Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
             return 0;
         }
         else
@@ -445,6 +499,7 @@ int main(int argc, char *argv[])
                 ofs << "secret = " << config.sSecret << std::endl;
             }
             ofs.close();
+            Util::setFilePermissions(config.sConfigFilePath, boost::filesystem::owner_read | boost::filesystem::owner_write);
             return 0;
         }
         else
