@@ -10,7 +10,7 @@
 #include <cstdio>
 #include <cstdlib>
 #include <sstream>
-#include <jsoncpp/json/json.h>
+#include <json/json.h>
 
 #if (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__) >= 40900
 #   define _regex_namespace_ std
@@ -233,14 +233,28 @@ std::string API::getResponse(const std::string& url)
     CURLcode result = curl_easy_perform(curlhandle);
     std::string response = memory.str();
     memory.str(std::string());
+
     if (result == CURLE_HTTP_RETURNED_ERROR)
     {
         long int response_code = 0;
         result = curl_easy_getinfo(curlhandle, CURLINFO_RESPONSE_CODE, &response_code);
         if (result == CURLE_OK)
-            this->setError("HTTP ERROR: " + std::to_string(response_code));
+            this->setError("HTTP ERROR: " + std::to_string(response_code) + " (" + url + ")");
         else
-            this->setError("HTTP ERROR: failed to get error code: " + static_cast<std::string>(curl_easy_strerror(result)));
+            this->setError("HTTP ERROR: failed to get error code: " + static_cast<std::string>(curl_easy_strerror(result)) + " (" + url + ")");
+
+        #ifdef DEBUG
+            curl_easy_setopt(curlhandle, CURLOPT_FAILONERROR, false);
+            result = curl_easy_perform(curlhandle);
+            std::string debug_response = memory.str();
+            memory.str(std::string());
+            std::cerr << "Response (CURLE_HTTP_RETURNED_ERROR):";
+            if (debug_response.empty())
+                std::cerr << " Response was empty" << std::endl;
+            else
+                std::cerr << std::endl << debug_response << std::endl;
+            curl_easy_setopt(curlhandle, CURLOPT_FAILONERROR, true);
+        #endif
     }
 
     return response;
@@ -518,9 +532,9 @@ gameDetails API::getGameDetails(const std::string& game_name, const unsigned int
 
                     if (!langpacknames.empty()) // found at least one language pack
                     {
-                        for (unsigned int i = 0; i < langpacknames.size(); ++i)
+                        for (unsigned int j = 0; j < langpacknames.size(); ++j)
                         {
-                            Json::Value langpack = root["game"][langpacknames[i]];
+                            Json::Value langpack = root["game"][langpacknames[j]];
                             game.languagepacks.push_back(
                                                         gameFile(   false, /* language packs don't have "updated" flag */
                                                                     langpack["id"].isInt() ? std::to_string(langpack["id"].asInt()) : langpack["id"].asString(),
