@@ -9,8 +9,9 @@
 #include <boost/filesystem.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
 #include <tinyxml.h>
-#include <jsoncpp/json/json.h>
+#include <json/json.h>
 #include <fstream>
+#include <sys/ioctl.h>
 
 /*
     Create filepath from specified directory and path
@@ -314,3 +315,30 @@ void Util::filepathReplaceReservedStrings(std::string& str, const std::string& g
     while (Util::replaceString(str, "%platform%", platform));
     while (Util::replaceString(str, "//", "/")); // Replace any double slashes with single slash
 }
+
+void Util::setFilePermissions(const boost::filesystem::path& path, const boost::filesystem::perms& permissions)
+{
+    if (boost::filesystem::exists(path))
+    {
+        if (boost::filesystem::is_regular_file(path))
+        {
+            boost::filesystem::file_status s = boost::filesystem::status(path);
+            if (s.permissions() != permissions)
+            {
+                boost::system::error_code ec;
+                boost::filesystem::permissions(path, permissions, ec);
+                if (ec)
+                {
+                    std::cout << "Failed to set file permissions for " << path.string() << std::endl;
+                }
+            }
+        }
+    }
+}
+
+int Util::getTerminalWidth()
+{
+    struct winsize w;
+    ioctl(STDOUT_FILENO, TIOCGWINSZ, &w);
+    return static_cast<int>(w.ws_col);
+}
